import hashlib
import os

class DownloadManager:
    def __init__(self, ssh_connector):
        self.ssh_connector = ssh_connector

    def download_file(self, remote_path, local_dir, local_file_name):
        try:
            os.makedirs(local_dir, exist_ok=True)
            local_path = os.path.join(local_dir, local_file_name)
            self.ssh_connector.download(remote_path, local_path)
            return os.path.exists(local_path)
        except Exception as e:
            print(f"Error downloading file: {e}")
            return False

    def verify_sha256(self, local_path, expected_sha256_path):
        try:
            file_sha256 = self._calculate_sha256(local_path)
            expected_sha256 = self._parse_expected_sha256(expected_sha256_path)
            return file_sha256 == expected_sha256
        except Exception as e:
            print(f"Error verifying SHA-256: {e}")
            return False

    def set_status(self, status, remote_path, status_file):
        try:
            self.ssh_connector.execute_command(f"echo {status} > {remote_path}/{status_file}")
        except Exception as e:
            print(f"Error setting status: {e}")

    def _calculate_sha256(self, file_path):
        sha256 = hashlib.sha256()
        try:
            with open(file_path, 'rb') as f:
                for chunk in iter(lambda: f.read(4096), b''):
                    sha256.update(chunk)
            return sha256.hexdigest()
        except FileNotFoundError:
            print(f"File not found: {file_path}")
            return None
        except Exception as e:
            print(f"Error calculating SHA-256: {e}")
            return None

    def _parse_expected_sha256(self, expected_sha256_path):
        try:
            with open(expected_sha256_path, 'r') as f:
                line = f.read().strip()
            return line.split()[0]
        except FileNotFoundError:
            print(f"Expected SHA-256 file not found: {expected_sha256_path}")
            return None
        except Exception as e:
            print(f"Error reading expected SHA-256: {e}")
            return None