import re
import os

class FileManager:
    @staticmethod
    def list_files(ls_output):
        file_groups = {}
        for file in map(str.strip, ls_output.split('\n')):
            match = re.match(r'^(.+)\.(\w+)\.(sha256|status)$', file)
            if match:
                file_name, file_type, file_status = match.groups()
                group_key = f"{file_name}.{file_type}"
                if group_key not in file_groups:
                    file_groups[group_key] = [f"{file_name}.{file_type}"]
                file_groups[group_key].append(f"{file_name}.{file_type}.{file_status}")
        
        sorted_file_groups = sorted(file_groups.values())
        return {'groups': sorted_file_groups, 'group_count': len(sorted_file_groups)}
    
    @staticmethod
    def verify_files(ssh_connector, backup, file_groups):
        if file_groups['group_count'] == 0:
            print("No files found on the remote server.")
            return
        
        if file_groups['group_count'] > 150:
            print("Too many files to verify. Please use --verify option for fewer files.")
            return
        
        skip_messages = ["failed", "download", "downloaded"]
        verify_message_printed = False
        verify_groups = []

        for group in file_groups['groups']:
            status_file = group[2]
            file_content = ssh_connector.execute_command(f"cat {backup['source_folder']}/{status_file}")
            file_status_message = file_content.strip()
            file_status = file_status_message == "ready"

            if not verify_message_printed and file_status_message not in skip_messages:
                print("Start verifying files...")
                verify_message_printed = True

            verify_groups.append([group[0], group[1], group[2], file_status])

        if verify_message_printed:
            print("Verification completed.")

        file_groups['verify_groups'] = verify_groups
        return file_groups

    @staticmethod
    def check_for_existing_local_files(local_dir, file_groups):
        return any(os.path.exists(f"{local_dir}/{file}") for file in file_groups)
